@@ -1,14 +1,16 @@
 package DBIx::Lite::ResultSet;
 {
-  $DBIx::Lite::ResultSet::VERSION = '0.12';
+  $DBIx::Lite::ResultSet::VERSION = '0.13';
 }
 use strict;
 use warnings;
 
+use Carp qw(croak);
 use Clone qw(clone);
 use Data::Page;
 use List::MoreUtils qw(uniq);
 use vars qw($AUTOLOAD);
+$Carp::Internal{$_}++ for __PACKAGE__;
 
 sub _new {
     my $class = shift;
@@ -25,7 +27,6 @@ sub _new {
         offset          => delete $params{offset},
         rows_per_page   => delete $params{rows_per_page} || 10,
         page            => delete $params{page},
-        pager           => delete $params{pager},
         cur_table       => delete $params{cur_table} || $params{table},
     };
     
@@ -47,6 +48,7 @@ for my $methname (qw(group_by having order_by limit offset rows_per_page page))
     
         my $new_self = $self->_clone;
         $new_self->{$methname} = $methname =~ /^(group_by|order_by)$/ ? [@_] : $_[0];
+        $new_self->{pager}->current_page($_[0]) if $methname eq 'page' && $new_self->{pager};
         $new_self;
     };
 }
@@ -55,7 +57,7 @@ sub _clone {
     my $self = shift;
     (ref $self)->_new(
         map { $_ => /^(?:dbix_lite|table|cur_table)$/ ? $self->{$_} : clone($self->{$_}) }
-            grep !/^(?:sth)$/, keys %$self,
+            grep !/^(?:sth|pager)$/, keys %$self,
     );
 }
 
@@ -112,7 +114,7 @@ sub select_sql {
     my @cols = ();
     my $have_scalar_ref = 0;
     my $cur_table_prefix = $self->_table_prefix($self->{cur_table}{name});
-    foreach my $col (@{$self->{select}}) {
+    foreach my $col (grep defined $_, @{$self->{select}}) {
         my ($expr, $as) = ref $col eq 'ARRAY' ? @$col : ($col, undef);
         $expr =~ s/^[^.]+$/$cur_table_prefix\.$&/ if !ref($expr);
         if (ref $expr eq 'SCALAR') {
@@ -133,8 +135,7 @@ sub select_sql {
     # joins
     my @joins = ();
     foreach my $join (@{$self->{joins}}) {
-        my ($table_name, $table_alias) = ref $join->[2] eq 'ARRAY'
-            ? @{$join->[2]} : ($join->[2], undef);
+        my ($table_name, $table_alias) = @{$join->[2]};
         my %cond = ();
         my $left_table_prefix = $self->_table_prefix($join->[1]{name});
         while (my ($col1, $col2) = each %{$join->[3]}) {
@@ -242,8 +243,8 @@ sub update_sql {
     }
     
     return $self->{dbix_lite}->{abstract}->update(
-        $self->{cur_table}{name}, $update_cols,
-        $update_where,
+        $self->{dbix_lite}->{abstract}->table_alias($self->{cur_table}{name}, $self->_table_prefix($self->{cur_table}{name})),
+        $update_cols, $update_where,
     );
 }
 
@@ -303,7 +304,8 @@ sub delete_sql {
     }
     
     return $self->{dbix_lite}->{abstract}->delete(
-        $self->{cur_table}{name}, $delete_where,
+        $self->{cur_table}{name},
+        $delete_where,
     );
 }
 
@@ -364,7 +366,7 @@ sub count {
     
     my $count;
     $self->{dbix_lite}->dbh_do(sub {
-        my $count_rs = ($self->_clone)->select(\ "COUNT(*)");
+        my $count_rs = ($self->_clone)->select(\ "-COUNT(*)");
         my ($sth, @bind) = $count_rs->select_sth;
         $sth->execute(@bind);
         $count = +($sth->fetchrow_array)[0];
@@ -398,10 +400,17 @@ sub left_join {
 
 sub _join {
     my $self = shift;
-    my ($type, $table_name, $condition) = @_;
+    my ($type, $table_name, $condition, $options) = @_;
+    $options ||= {};
+    $table_name = [ $table_name, undef ] if ref $table_name ne 'ARRAY';
     
     my $new_self = $self->_clone;
-    push @{$new_self->{joins}}, [$type, $self->{cur_table}, $table_name, $condition];
+    push @{$new_self->{joins}}, [
+        $type,
+        $self->{cur_table},
+        $table_name,
+        $condition,
+    ] if !$options->{prevent_duplicates} || !grep { $_->[2][0] eq $table_name->[0] } @{$new_self->{joins}};
     $new_self;
 }
 
@@ -453,7 +462,7 @@ DBIx::Lite::ResultSet
 
 =head1 VERSION
 
-version 0.12
+version 0.13
 
 =head1 OVERVIEW
 
@@ -567,6 +576,12 @@ The join conditions are in the form I<my columns> => I<their columns>. In the ab
 example, we're selecting from the I<books> table to the I<authors> table, so the join 
 condition maps I<my> C<author_id> column to I<their> C<id> column.
 
+The third, optional, argument can be a hashref with options. The only supported one
+is currently I<prevent_duplicates>: set this to true to have DBIx::Lite check whether
+you already joined the same table in this query. If you did, this join will be skipped:
+
+    my $rs = $books_rs->inner_join('authors', { author_id => 'id' }, { prevent_duplicates => 1 });
+
 =head2 left_join
 
 This method works like L<inner join> except it applies a C<LEFT JOIN> instead of an
